==> haskell-dataenc-0.14.0.7-31-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-dataenc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dataenc
version:              0.14.0.7
visibility:           public
id:                   dataenc-0.14.0.7-GGX9kypg0AdLIeoMPt3fwf
key:                  dataenc-0.14.0.7-GGX9kypg0AdLIeoMPt3fwf
license:              BSD-3-Clause
copyright:            Magnus Therning, 2007-2012, Gracjan Polak, 2014
maintainer:           Gracjan Polak <gracjanpolak@gmail.com>
author:               Magnus Therning
homepage:             http://www.haskell.org/haskellwiki/Library/Data_encoding
synopsis:             Data encoding library
description:
    Data encoding library currently providing Base16, Base32,
    Base32Hex, Base64, Base64Url, Base85, Python string escaping,
    Quoted-Printable, URL encoding, uuencode, xxencode, and yEncoding.

category:             Codec
abi:                  2ba8a3a84253e6ea0e966cc1846d56e2
exposed:              True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.DataEncoding Codec.Binary.PythonString
    Codec.Binary.QuotedPrintable Codec.Binary.Url Codec.Binary.Uu
    Codec.Binary.Xx Codec.Binary.Yenc

hidden-modules:       Codec.Binary.Util
import-dirs:          /usr/lib/ghc-9.2.8/site-local/dataenc-0.14.0.7
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dataenc-0.14.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dataenc
hs-libraries:         HSdataenc-0.14.0.7-GGX9kypg0AdLIeoMPt3fwf
depends:              array-0.5.4.0 base-4.16.4.0 containers-0.6.5.1
haddock-interfaces:   /usr/share/doc/haskell-dataenc/html/dataenc.haddock
haddock-html:         /usr/share/doc/haskell-dataenc/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dataenc-0.14.0.7-32-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-dataenc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 dataenc
version:              0.14.0.7
visibility:           public
id:                   dataenc-0.14.0.7-Fw6Zd7meeCK9CLxlZhg8z4
key:                  dataenc-0.14.0.7-Fw6Zd7meeCK9CLxlZhg8z4
license:              BSD-3-Clause
copyright:            Magnus Therning, 2007-2012, Gracjan Polak, 2014
maintainer:           Gracjan Polak <gracjanpolak@gmail.com>
author:               Magnus Therning
homepage:             http://www.haskell.org/haskellwiki/Library/Data_encoding
synopsis:             Data encoding library
description:
    Data encoding library currently providing Base16, Base32,
    Base32Hex, Base64, Base64Url, Base85, Python string escaping,
    Quoted-Printable, URL encoding, uuencode, xxencode, and yEncoding.

category:             Codec
abi:                  5c63108e7d7d349e10f8d5d326d0a030
exposed:              True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.DataEncoding Codec.Binary.PythonString
    Codec.Binary.QuotedPrintable Codec.Binary.Url Codec.Binary.Uu
    Codec.Binary.Xx Codec.Binary.Yenc

hidden-modules:       Codec.Binary.Util
import-dirs:          /usr/lib/ghc-9.4.8/site-local/dataenc-0.14.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/dataenc-0.14.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/dataenc-0.14.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-dataenc
hs-libraries:         HSdataenc-0.14.0.7-Fw6Zd7meeCK9CLxlZhg8z4
depends:              array-0.5.4.0 base-4.17.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-dataenc/html/dataenc.haddock
haddock-html:         /usr/share/doc/haskell-dataenc/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
